@@ -34,7 +34,7 @@
 #define __KLEO_UI_DNATTRIBUTEORDERCONFIGWIDGET_H__
 
 #include <tqwidget.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 namespace Kleo {
   class DNAttributeMapper;
 }
