@@ -149,16 +149,16 @@ KNotesApp::KNotesApp()
     // create accels for global shortcuts
     m_globalAccel = new TDEGlobalAccel( TQT_TQOBJECT(this), "global accel" );
     m_globalAccel->insert( "global_new_note", i18n("New Note"), "",
-                           ALT+SHIFT+Key_N, ALT+SHIFT+Key_N ,
+                           TDEShortcut(), TDEShortcut(),
                            TQT_TQOBJECT(this), TQT_SLOT(newNote()), true, true );
     m_globalAccel->insert( "global_new_note_clipboard", i18n("New Note From Clipboard"), "",
-                           ALT+SHIFT+Key_C, ALT+SHIFT+Key_C,
+                           TDEShortcut(), TDEShortcut(),
                            TQT_TQOBJECT(this), TQT_SLOT(newNoteFromClipboard()), true, true );
     m_globalAccel->insert( "global_hide_all_notes", i18n("Hide All Notes"), "",
-                           ALT+SHIFT+Key_H, ALT+SHIFT+Key_H ,
+                           TDEShortcut(), TDEShortcut(),
                            TQT_TQOBJECT(this), TQT_SLOT(hideAllNotes()), true, true );
     m_globalAccel->insert( "global_show_all_notes", i18n("Show All Notes"), "",
-                           ALT+SHIFT+Key_S, ALT+SHIFT+Key_S,
+                           TDEShortcut(), TDEShortcut(),
                            TQT_TQOBJECT(this), TQT_SLOT(showAllNotes()), true, true );
 
     m_globalAccel->readSettings();
