@@ -40,7 +40,7 @@
 #include <tqcstring.h> // TQByteArray
 
 #include <kdebug.h> // for kdFatal()
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace KMime {
 
