@@ -22,7 +22,7 @@
 #include <gpgmepp/interfaces/dataprovider.h>
 
 #include <tqcstring.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace QGpgME {
 
