@@ -31,7 +31,7 @@
 #include <tqstringlist.h>
 #include <tqptrlist.h>
 #include <tqptrdict.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace KPIM {
 
