@@ -9,7 +9,7 @@
 
 #include <tdeversion.h>
 #include <tdeabc/addressee.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace TDEABC {
   class AddressBook;
