@@ -29,7 +29,7 @@ extern "C"
 #include <tqmutex.h>
 #include <tqevent.h>
 
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace KPIM {
 namespace ThreadWeaver {
